@@ -258,6 +258,7 @@ static config_conf const conf[] =
 	CONFIG(parm_t, sign_hfields, "space-separated, no colon", assign_array),
 	CONFIG(parm_t, oversign_hfields, "space-separated, no colon", assign_array),
 	CONFIG(parm_t, skip_hfields, "space-separated, no colon", assign_array),
+	CONFIG(parm_t, xtag_value, "extension tag=value", assign_ptr),
 	CONFIG(parm_t, no_signlen, "Y/N", assign_char),
 	CONFIG(parm_t, no_qp_conversion, "Y/N", assign_char),
 	CONFIG(parm_t, min_key_bits, "int", assign_int),
@@ -276,10 +277,10 @@ static config_conf const conf[] =
 	CONFIG(parm_t, disable_experimental, "Y/N", assign_char),
 	CONFIG(parm_t, noaddrrewrite, "Y/N", assign_char),
 	CONFIG(parm_t, still_allow_no_from, "Y/N", assign_char),
+	CONFIG(parm_t, checkhelo_if_no_auth, "Y/N", assign_char),
 	CONFIG(parm_t, max_signatures, "int", assign_int),
 	CONFIG(parm_t, log_dkim_order_above, "int", assign_int),
 	CONFIG(parm_t, publicsuffix, "filename", assign_ptr),
-	CONFIG(parm_t, psddmarc, "filename", assign_ptr),
 	CONFIG(parm_t, honored_report_interval, "seconds", assign_int),
 	CONFIG(parm_t, honor_dmarc, "Y/N", assign_char),
 	CONFIG(parm_t, honor_author_domain, "Y/N", assign_char),
